import { Database } from 'bun:sqlite';
import { DB_PATH } from './config';
import { logger } from './globals';

export let FTS5Enabled = true;

export const initializeDB = () => {
    logger.info("Checking fts");
    const ftstest = db.query(`pragma compile_options;`);
    const result = ftstest.all() as { compile_options: string }[];
    if (result.find((o) => o["compile_options"].includes("ENABLE_FTS5"))) {
        logger.info("FTS5 is enabled");
    } else {
        logger.info("FTS5 is not enabled. Attempting to load...");
        try {
            db.loadExtension('./fts5');
        } catch (e) {
            logger.warn("Failed to load FTS5 extension. Disabling FTS5");
            FTS5Enabled = false;
        }

    }


    db.run(`
      CREATE TABLE IF NOT EXISTS channels (
        id INTEGER PRIMARY KEY AUTOINCREMENT,
        name TEXT NOT NULL,
        createdAt DATETIME DEFAULT CURRENT_TIMESTAMP
      )
    `);

    db.run(`
      CREATE TABLE IF NOT EXISTS files (
        id INTEGER PRIMARY KEY AUTOINCREMENT,
        channelId INTEGER,
        filePath TEXT,
        fileType TEXT,
        fileSize INTEGER,
        originalName TEXT,
        createdAt DATETIME DEFAULT CURRENT_TIMESTAMP,
        FOREIGN KEY (channelId) REFERENCES channels (id) ON DELETE CASCADE
      )
    `);

    db.run(`
      CREATE TABLE IF NOT EXISTS messages (
        id INTEGER PRIMARY KEY AUTOINCREMENT,
        channelId INTEGER,
        content TEXT,
        fileId INTEGER NULL,
        createdAt DATETIME DEFAULT CURRENT_TIMESTAMP,
        FOREIGN KEY (channelId) REFERENCES channels (id) ON DELETE CASCADE,
        FOREIGN KEY (fileId) REFERENCES files (id) ON DELETE SET NULL
      )
    `);

    db.run(`
      CREATE VIRTUAL TABLE IF NOT EXISTS messages_fts USING fts5(
        content,
        content='messages',
        content_rowid='id'
      );
    `)

    return FTS5Enabled;
}

logger.info(`Loading database at ${DB_PATH}`);
export const db = new Database(DB_PATH);


initializeDB();